#!/usr/bin/env python3

import sys
import numpy as np
import xarray as xr
import cartopy.crs as ccrs


import matplotlib.pyplot as plt
import matplotlib.ticker as mticker

import cartopy.mpl.ticker as cticker
from cartopy.mpl.ticker import LongitudeFormatter, LatitudeFormatter


fins_ini = ['glac0.3_thk_topg_1_notime_select.nc',
       'pma10.3_thk_topg_1_notime_select.nc',
       'pism0.3_thk_topg_1_notime_select.nc',
       ]

fins1 = ['glac0.3_thk_topg_119_notime_select.nc', 'pma10.3_thk_topg_180_notime_select.nc','pism0.3_thk_topg_171_notime_select.nc', ]


fins_recon = ['glac1d_thk_notime_select.nc',
        'paleomist_thk_notime_select.nc',
        'ice6g_thk_notime_select.nc',]





titles = ['Tran_Glac1d', 'Tran_Paleomist', 'Tran_PISMindex', ]
titles2 = ['Glac1D', 'Paleomist', 'PISM-index', ]
color1 = ['red','blue','black']
font_dict = {'family':'serif','size':15}

nfile = len(fins_ini)

####### ice reconstruction 21 ka ##########--start
with xr.open_dataset(fins_recon[0],decode_times=False) as ff:
    thk_glac1d = ff['thk'].values[:,:]

with xr.open_dataset(fins_recon[1],decode_times=False) as ff:
    thk_paleomist = ff['thk'].values[:,:]

with xr.open_dataset(fins_recon[2],decode_times=False) as ff:
    thk_ice6g = ff['thk'].values[:,:]

######### --end



### definition for plots
minval = 0
maxval = 5000
nbreaks = 51

breaks = np.linspace(minval,maxval,nbreaks)
color = plt.cm.PuBuGn_r
color2 = plt.cm.cividis
breaks2 = np.linspace(-5000,3000,81)
breaks3 = np.arange(0,5000,500)


projection = ccrs.NorthPolarStereo(central_longitude= -45,true_scale_latitude=70.,globe=None)
print('pro4_params: ',projection.proj4_params)
projection2 = ccrs.NorthPolarStereo(central_longitude= -135,true_scale_latitude=70.,globe=None)


fig = plt.figure(figsize=(14,8))
fig.subplots_adjust(left=0.02,right=0.88, top=0.95, bottom=0.01, hspace=0.01,wspace=0.05)



for i in range(0,nfile):
    with xr.open_dataset(fins_ini[i],decode_times=False) as ff:
        thk = ff['thk'].values
        topg = ff['topg'].values
        x = ff['x'].values[:]
        y = ff['y'].values[:]


    thknew = np.ma.masked_where(thk < 1., thk )
    usurf = thk + topg

    new_extent = [np.min(x), np.max(x), np.max(y), np.min(y)]
    plot_extent = [-5990000.0, 900000.0, 1500000, -5900000.0]


    ax = plt.subplot(2,3,i+1,projection=projection2)
    ax.set_extent(plot_extent,projection)


    cs = plt.contourf(x, y, topg, transform=projection,extent=new_extent, extend='both', cmap=color2 , levels=breaks2)
    cs2 = plt.contourf(x, y, thknew, transform=projection,extent=new_extent,extend='both',cmap=color,levels=breaks,vmin=minval,vmax=maxval)
    cs3 = plt.contour(x, y, usurf,  transform=projection,extent=new_extent, colors='black', levels=breaks3,linewidths=0.7 )
    plt.clabel(cs3,  fontsize=10)
    plt.contour(x, y, thk_glac1d, transform=projection,extent=new_extent, colors='khaki', levels=[10.],linewidths=1 )
    plt.contour(x, y, thk_paleomist, transform=projection,extent=new_extent, colors='sandybrown', levels=[0.],linewidths=1 )
    plt.contour(x, y, thk_ice6g,  transform=projection,extent=new_extent, colors='bisque', levels=[0.],linewidths=1 )

    gl = ax.gridlines(draw_labels=True) #, linewidth=2, alpha=0.4, color='k', linestyle=':')
    gl.xlines = True
    gl.ylines = True
    gl.bottom_labels = False
    gl.xlabel_style = {'size': 12, 'color': 'black', } #'weight': 'bold'}
    gl.ylabel_style = {'size': 12, 'color': 'black',  } #'weight': 'bold'}

    ##############
    ##################

    with xr.open_dataset(fins1[i],decode_times=False) as ff:
        thk = ff['thk'].values[:,:]
        topg = ff['topg'].values[:,:]

    thknew = np.ma.masked_where(thk < 1, thk )
    usurf = thk + topg

    #-------- plot --------
    ax = plt.subplot(2,3,i+4,projection=projection2)
    ax.set_extent(plot_extent,projection)

    cs = plt.contourf(x, y, topg, transform=projection,extent=new_extent, extend='both', cmap=color2 , levels=breaks2)  #colors='grey'
    cs2 = plt.contourf(x, y, thknew, transform=projection,extent=new_extent,extend='both',cmap=color,levels=breaks,vmin=minval,vmax=maxval)
    cs3 = plt.contour(x, y, usurf,  transform=projection,extent=new_extent, colors='black', levels=breaks3,linewidths=0.7 )
    plt.clabel(cs3,  fontsize=10)
    plt.contour(x, y, thk_glac1d,  transform=projection,extent=new_extent, colors='khaki', levels=[10.],linewidths=1 )
    plt.contour(x, y, thk_paleomist, transform=projection,extent=new_extent, colors='sandybrown', levels=[10.],linewidths=1 )
    plt.contour(x, y, thk_ice6g, transform=projection,extent=new_extent, colors='bisque', levels=[10.],linewidths=1 )

    gl = ax.gridlines(draw_labels=True) #, linewidth=2, alpha=0.4, color='k', linestyle=':')
    gl.xlines = True
    gl.ylines = True #False
    gl.bottom_labels = False
    gl.top_labels = False
    gl.xlabel_style = {'size': 12, 'color': 'black', } #'weight': 'bold'}
    gl.ylabel_style = {'size': 12, 'color': 'black',  } #'weight': 'bold'}

    fig.text(0.15+i*0.28, 0.95, titles[i],fontdict={'family':'serif','color':color1[i],'size':20,}) #'weight':'bold'


cax = plt.axes([0.9,0.06,0.02,0.8])
cbar = plt.colorbar(cs2, cax=cax,orientation='vertical',fraction=0.05,pad=0.03)
cbar.set_label(label='Ice thickness (m)', size=20)
cbar.set_ticks(np.arange(0,4800+1,800))
cbar.ax.tick_params(labelsize=15)




plt.savefig('Figure1b-g.png')
plt.show(block=False)
plt.close()
